==> react-ui-library-0.7.1.tgz: package/src/stories/link-story.js <==
import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Pane,
  Content,
  Link,
  Text
} from '../components'

export default function linkStory (module) {
  storiesOf('Link', module)
    .add('usage', () => (
      <App white>
        <Pane white padding={10}>
          <Content markdown>
{`
# Link

The Link component is a \`a\` or \`span\` element. Implement the \`<Text />\` component.

\`\`\`
<Text textStyle='body1'>
  <Link underline href=''>Primary Link by default</Link><br/>
  <Link underline secondary href=''>Secondary Link</Link><br/>
  <Link underline danger href=''>danger Link</Link><br/>
  <Link underline={false} active href=''>Active Link becomes a span</Link>
</Text>
<Text textStyle='display2'>
  <Link underline href=''>Primary Link by default</Link><br/>
</Text>
\`\`\`

`}
          </Content>
          <Text textStyle='body1'>
            <Link underline href=''>Primary Link by default</Link><br/>
            <Link underline secondary href=''>Secondary Link</Link><br/>
            <Link underline danger href=''>danger Link</Link><br/>
            <Link underline={false} active href=''>Active Link becomes a span</Link>
          </Text>
          <Text textStyle='display2'>
            <Link underline href=''>Primary Link by default</Link><br/>
          </Text>
          <Content markdown>
{`
prop | type | default | description
-----|------|----------|-------------
\`underline\` | boolean | true | text-decoration: underline;
\`primary\` | boolean | true |primary intent styling
\`secondary\` | boolean | undefined | secondary intent styling
\`danger\` | boolean | undefined | danger intent styling
\`active\` | boolean | undefined | becomes a span and gets active className
`}
          </Content>
        </Pane>
      </App>
    ))
}

==> react-ui-library-2.0.0.tgz: package/src/stories/link-story.js <==
import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Pane,
  Content,
  Link,
  Text,
  theme
} from '../components'
const { minorScale, majorScale } = theme

export default function linkStory (module) {
  storiesOf('Link', module)
    .add('usage', () => (
      <App white>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
{`
# Link

The Link component is a \`a\` or \`span\` element. Implement the \`<Text />\` component.

\`\`\`
<Text textStyle='body1'>
  <Link underline href=''>Primary Link by default</Link><br/>
  <Link underline secondary href=''>Secondary Link</Link><br/>
  <Link underline danger href=''>danger Link</Link><br/>
  <Link underline={false} active href=''>Active Link becomes a span</Link>
</Text>
<Text textStyle='display2'>
  <Link underline href=''>Primary Link by default</Link><br/>
</Text>
\`\`\`

`}
          </Content>
          <Text textStyle='body1'>
            <Link underline href=''>Primary Link by default</Link><br/>
            <Link underline secondary href=''>Secondary Link</Link><br/>
            <Link underline danger href=''>danger Link</Link><br/>
            <Link underline={false} active href=''>Active Link becomes a span</Link>
          </Text>
          <Text textStyle='display2'>
            <Link underline href=''>Primary Link by default</Link><br/>
          </Text>
          <Content markdown>
{`
prop | type | default | description
-----|------|----------|-------------
\`underline\` | boolean | true | text-decoration: underline;
\`primary\` | boolean | true |primary intent styling
\`secondary\` | boolean | undefined | secondary intent styling
\`danger\` | boolean | undefined | danger intent styling
\`active\` | boolean | undefined | becomes a span and gets active className
`}
          </Content>
        </Pane>
      </App>
    ))
}
